"""
Type annotations for connectparticipant service type definitions.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from mypy_boto3_connectparticipant.type_defs import AttachmentItemTypeDef

    data: AttachmentItemTypeDef = ...
    ```
"""

from __future__ import annotations

import sys

from .literals import (
    ArtifactStatusType,
    ChatItemTypeType,
    ConnectionTypeType,
    MeetingFeatureStatusType,
    ParticipantRoleType,
    ScanDirectionType,
    SortKeyType,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import list as List
    from collections.abc import Sequence
else:
    from typing import Dict, List, Sequence
if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict


__all__ = (
    "AttachmentItemTypeDef",
    "AttendeeTypeDef",
    "AudioFeaturesTypeDef",
    "CancelParticipantAuthenticationRequestTypeDef",
    "CompleteAttachmentUploadRequestTypeDef",
    "ConnectionCredentialsTypeDef",
    "CreateParticipantConnectionRequestTypeDef",
    "CreateParticipantConnectionResponseTypeDef",
    "DescribeViewRequestTypeDef",
    "DescribeViewResponseTypeDef",
    "DisconnectParticipantRequestTypeDef",
    "GetAttachmentRequestTypeDef",
    "GetAttachmentResponseTypeDef",
    "GetAuthenticationUrlRequestTypeDef",
    "GetAuthenticationUrlResponseTypeDef",
    "GetTranscriptRequestTypeDef",
    "GetTranscriptResponseTypeDef",
    "ItemTypeDef",
    "MeetingFeaturesConfigurationTypeDef",
    "MessageMetadataTypeDef",
    "ReceiptTypeDef",
    "ResponseMetadataTypeDef",
    "SendEventRequestTypeDef",
    "SendEventResponseTypeDef",
    "SendMessageRequestTypeDef",
    "SendMessageResponseTypeDef",
    "StartAttachmentUploadRequestTypeDef",
    "StartAttachmentUploadResponseTypeDef",
    "StartPositionTypeDef",
    "UploadMetadataTypeDef",
    "ViewContentTypeDef",
    "ViewTypeDef",
    "WebRTCConnectionTypeDef",
    "WebRTCMediaPlacementTypeDef",
    "WebRTCMeetingTypeDef",
    "WebsocketTypeDef",
)


class AttachmentItemTypeDef(TypedDict):
    ContentType: NotRequired[str]
    AttachmentId: NotRequired[str]
    AttachmentName: NotRequired[str]
    Status: NotRequired[ArtifactStatusType]


class AttendeeTypeDef(TypedDict):
    AttendeeId: NotRequired[str]
    JoinToken: NotRequired[str]


class AudioFeaturesTypeDef(TypedDict):
    EchoReduction: NotRequired[MeetingFeatureStatusType]


class CancelParticipantAuthenticationRequestTypeDef(TypedDict):
    SessionId: str
    ConnectionToken: str


class CompleteAttachmentUploadRequestTypeDef(TypedDict):
    AttachmentIds: Sequence[str]
    ClientToken: str
    ConnectionToken: str


class ConnectionCredentialsTypeDef(TypedDict):
    ConnectionToken: NotRequired[str]
    Expiry: NotRequired[str]


CreateParticipantConnectionRequestTypeDef = TypedDict(
    "CreateParticipantConnectionRequestTypeDef",
    {
        "ParticipantToken": str,
        "Type": NotRequired[Sequence[ConnectionTypeType]],
        "ConnectParticipant": NotRequired[bool],
    },
)


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class WebsocketTypeDef(TypedDict):
    Url: NotRequired[str]
    ConnectionExpiry: NotRequired[str]


class DescribeViewRequestTypeDef(TypedDict):
    ViewToken: str
    ConnectionToken: str


class DisconnectParticipantRequestTypeDef(TypedDict):
    ConnectionToken: str
    ClientToken: NotRequired[str]


class GetAttachmentRequestTypeDef(TypedDict):
    AttachmentId: str
    ConnectionToken: str
    UrlExpiryInSeconds: NotRequired[int]


class GetAuthenticationUrlRequestTypeDef(TypedDict):
    SessionId: str
    RedirectUri: str
    ConnectionToken: str


class StartPositionTypeDef(TypedDict):
    Id: NotRequired[str]
    AbsoluteTime: NotRequired[str]
    MostRecent: NotRequired[int]


class ReceiptTypeDef(TypedDict):
    DeliveredTimestamp: NotRequired[str]
    ReadTimestamp: NotRequired[str]
    RecipientParticipantId: NotRequired[str]


class SendEventRequestTypeDef(TypedDict):
    ContentType: str
    ConnectionToken: str
    Content: NotRequired[str]
    ClientToken: NotRequired[str]


class SendMessageRequestTypeDef(TypedDict):
    ContentType: str
    Content: str
    ConnectionToken: str
    ClientToken: NotRequired[str]


class StartAttachmentUploadRequestTypeDef(TypedDict):
    ContentType: str
    AttachmentSizeInBytes: int
    AttachmentName: str
    ClientToken: str
    ConnectionToken: str


class UploadMetadataTypeDef(TypedDict):
    Url: NotRequired[str]
    UrlExpiry: NotRequired[str]
    HeadersToInclude: NotRequired[Dict[str, str]]


class ViewContentTypeDef(TypedDict):
    InputSchema: NotRequired[str]
    Template: NotRequired[str]
    Actions: NotRequired[List[str]]


class WebRTCMediaPlacementTypeDef(TypedDict):
    AudioHostUrl: NotRequired[str]
    AudioFallbackUrl: NotRequired[str]
    SignalingUrl: NotRequired[str]
    EventIngestionUrl: NotRequired[str]


class MeetingFeaturesConfigurationTypeDef(TypedDict):
    Audio: NotRequired[AudioFeaturesTypeDef]


class GetAttachmentResponseTypeDef(TypedDict):
    Url: str
    UrlExpiry: str
    AttachmentSizeInBytes: int
    ResponseMetadata: ResponseMetadataTypeDef


class GetAuthenticationUrlResponseTypeDef(TypedDict):
    AuthenticationUrl: str
    ResponseMetadata: ResponseMetadataTypeDef


class SendEventResponseTypeDef(TypedDict):
    Id: str
    AbsoluteTime: str
    ResponseMetadata: ResponseMetadataTypeDef


class SendMessageResponseTypeDef(TypedDict):
    Id: str
    AbsoluteTime: str
    ResponseMetadata: ResponseMetadataTypeDef


class GetTranscriptRequestTypeDef(TypedDict):
    ConnectionToken: str
    ContactId: NotRequired[str]
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]
    ScanDirection: NotRequired[ScanDirectionType]
    SortOrder: NotRequired[SortKeyType]
    StartPosition: NotRequired[StartPositionTypeDef]


class MessageMetadataTypeDef(TypedDict):
    MessageId: NotRequired[str]
    Receipts: NotRequired[List[ReceiptTypeDef]]


class StartAttachmentUploadResponseTypeDef(TypedDict):
    AttachmentId: str
    UploadMetadata: UploadMetadataTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class ViewTypeDef(TypedDict):
    Id: NotRequired[str]
    Arn: NotRequired[str]
    Name: NotRequired[str]
    Version: NotRequired[int]
    Content: NotRequired[ViewContentTypeDef]


class WebRTCMeetingTypeDef(TypedDict):
    MediaPlacement: NotRequired[WebRTCMediaPlacementTypeDef]
    MeetingFeatures: NotRequired[MeetingFeaturesConfigurationTypeDef]
    MeetingId: NotRequired[str]


ItemTypeDef = TypedDict(
    "ItemTypeDef",
    {
        "AbsoluteTime": NotRequired[str],
        "Content": NotRequired[str],
        "ContentType": NotRequired[str],
        "Id": NotRequired[str],
        "Type": NotRequired[ChatItemTypeType],
        "ParticipantId": NotRequired[str],
        "DisplayName": NotRequired[str],
        "ParticipantRole": NotRequired[ParticipantRoleType],
        "Attachments": NotRequired[List[AttachmentItemTypeDef]],
        "MessageMetadata": NotRequired[MessageMetadataTypeDef],
        "RelatedContactId": NotRequired[str],
        "ContactId": NotRequired[str],
    },
)


class DescribeViewResponseTypeDef(TypedDict):
    View: ViewTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class WebRTCConnectionTypeDef(TypedDict):
    Attendee: NotRequired[AttendeeTypeDef]
    Meeting: NotRequired[WebRTCMeetingTypeDef]


class GetTranscriptResponseTypeDef(TypedDict):
    InitialContactId: str
    Transcript: List[ItemTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class CreateParticipantConnectionResponseTypeDef(TypedDict):
    Websocket: WebsocketTypeDef
    ConnectionCredentials: ConnectionCredentialsTypeDef
    WebRTCConnection: WebRTCConnectionTypeDef
    ResponseMetadata: ResponseMetadataTypeDef



"""
Main interface for connectparticipant service.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_connectparticipant import (
        Client,
        ConnectParticipantClient,
    )

    session = Session()
    client: ConnectParticipantClient = session.client("connectparticipant")
    ```
"""

from .client import ConnectParticipantClient

Client = ConnectParticipantClient

__all__ = ("Client", "ConnectParticipantClient")



"""
Type annotations for connectparticipant service Client.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_connectparticipant.client import ConnectParticipantClient

    session = Session()
    client: ConnectParticipantClient = session.client("connectparticipant")
    ```
"""

from __future__ import annotations

import sys
from typing import Any

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .type_defs import (
    CancelParticipantAuthenticationRequestTypeDef,
    CompleteAttachmentUploadRequestTypeDef,
    CreateParticipantConnectionRequestTypeDef,
    CreateParticipantConnectionResponseTypeDef,
    DescribeViewRequestTypeDef,
    DescribeViewResponseTypeDef,
    DisconnectParticipantRequestTypeDef,
    GetAttachmentRequestTypeDef,
    GetAttachmentResponseTypeDef,
    GetAuthenticationUrlRequestTypeDef,
    GetAuthenticationUrlResponseTypeDef,
    GetTranscriptRequestTypeDef,
    GetTranscriptResponseTypeDef,
    SendEventRequestTypeDef,
    SendEventResponseTypeDef,
    SendMessageRequestTypeDef,
    SendMessageResponseTypeDef,
    StartAttachmentUploadRequestTypeDef,
    StartAttachmentUploadResponseTypeDef,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import type as Type
    from collections.abc import Mapping
else:
    from typing import Dict, Mapping, Type
if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = ("ConnectParticipantClient",)

class Exceptions(BaseClientExceptions):
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]

class ConnectParticipantClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant.html#ConnectParticipant.Client)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        ConnectParticipantClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant.html#ConnectParticipant.Client)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/can_paginate.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/generate_presigned_url.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#generate_presigned_url)
        """

    def cancel_participant_authentication(
        self, **kwargs: Unpack[CancelParticipantAuthenticationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Cancels the authentication session.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/cancel_participant_authentication.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#cancel_participant_authentication)
        """

    def complete_attachment_upload(
        self, **kwargs: Unpack[CompleteAttachmentUploadRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Allows you to confirm that the attachment has been uploaded using the
        pre-signed URL provided in StartAttachmentUpload API.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/complete_attachment_upload.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#complete_attachment_upload)
        """

    def create_participant_connection(
        self, **kwargs: Unpack[CreateParticipantConnectionRequestTypeDef]
    ) -> CreateParticipantConnectionResponseTypeDef:
        """
        Creates the participant's connection.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/create_participant_connection.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#create_participant_connection)
        """

    def describe_view(
        self, **kwargs: Unpack[DescribeViewRequestTypeDef]
    ) -> DescribeViewResponseTypeDef:
        """
        Retrieves the view for the specified view token.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/describe_view.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#describe_view)
        """

    def disconnect_participant(
        self, **kwargs: Unpack[DisconnectParticipantRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Disconnects a participant.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/disconnect_participant.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#disconnect_participant)
        """

    def get_attachment(
        self, **kwargs: Unpack[GetAttachmentRequestTypeDef]
    ) -> GetAttachmentResponseTypeDef:
        """
        Provides a pre-signed URL for download of a completed attachment.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/get_attachment.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#get_attachment)
        """

    def get_authentication_url(
        self, **kwargs: Unpack[GetAuthenticationUrlRequestTypeDef]
    ) -> GetAuthenticationUrlResponseTypeDef:
        """
        Retrieves the AuthenticationUrl for the current authentication session for the
        AuthenticateCustomer flow block.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/get_authentication_url.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#get_authentication_url)
        """

    def get_transcript(
        self, **kwargs: Unpack[GetTranscriptRequestTypeDef]
    ) -> GetTranscriptResponseTypeDef:
        """
        Retrieves a transcript of the session, including details about any attachments.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/get_transcript.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#get_transcript)
        """

    def send_event(self, **kwargs: Unpack[SendEventRequestTypeDef]) -> SendEventResponseTypeDef:
        """
        The
        <code>application/vnd.amazonaws.connect.event.connection.acknowledged</code>
        ContentType is no longer maintained since December 31, 2024.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/send_event.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#send_event)
        """

    def send_message(
        self, **kwargs: Unpack[SendMessageRequestTypeDef]
    ) -> SendMessageResponseTypeDef:
        """
        Sends a message.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/send_message.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#send_message)
        """

    def start_attachment_upload(
        self, **kwargs: Unpack[StartAttachmentUploadRequestTypeDef]
    ) -> StartAttachmentUploadResponseTypeDef:
        """
        Provides a pre-signed Amazon S3 URL in response for uploading the file directly
        to S3.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connectparticipant/client/start_attachment_upload.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connectparticipant/client/#start_attachment_upload)
        """
